@@ -5,7 +5,9 @@
 */
 
 #include <cstdint>
+#include <cstdlib>
 #include <iostream>
+#include <string>
 
 #include <osmium/io/any_input.hpp>
 #include <osmium/handler.hpp>
@@ -17,15 +19,15 @@ struct CountHandler : public osmium::handler::Handler {
     uint64_t ways = 0;
     uint64_t relations = 0;
 
-    void node(osmium::Node&) {
+    void node(const osmium::Node&) {
         ++nodes;
     }
 
-    void way(osmium::Way&) {
+    void way(const osmium::Way&) {
         ++ways;
     }
 
-    void relation(osmium::Relation&) {
+    void relation(const osmium::Relation&) {
         ++relations;
     }
 
@@ -35,12 +37,12 @@ struct CountHandler : public osmium::handler::Handler {
 int main(int argc, char* argv[]) {
     if (argc != 2) {
         std::cerr << "Usage: " << argv[0] << " OSMFILE\n";
-        exit(1);
+        std::exit(1);
     }
 
-    std::string input_filename = argv[1];
+    const std::string input_filename{argv[1]};
 
-    osmium::io::Reader reader(input_filename);
+    osmium::io::Reader reader{input_filename};
 
     CountHandler handler;
     osmium::apply(reader, handler);
