@@ -5,7 +5,9 @@
 */
 
 #include <cstdint>
+#include <cstdlib>
 #include <iostream>
+#include <string>
 
 #include <osmium/io/any_input.hpp>
 #include <osmium/handler.hpp>
@@ -16,7 +18,7 @@ struct CountHandler : public osmium::handler::Handler {
     uint64_t counter = 0;
     uint64_t all = 0;
 
-    void node(osmium::Node& node) {
+    void node(const osmium::Node& node) {
         ++all;
         const char* amenity = node.tags().get_value_by_key("amenity");
         if (amenity && !strcmp(amenity, "post_box")) {
@@ -24,11 +26,11 @@ struct CountHandler : public osmium::handler::Handler {
         }
     }
 
-    void way(osmium::Way&) {
+    void way(const osmium::Way&) {
         ++all;
     }
 
-    void relation(osmium::Relation&) {
+    void relation(const osmium::Relation&) {
         ++all;
     }
 
@@ -38,12 +40,12 @@ struct CountHandler : public osmium::handler::Handler {
 int main(int argc, char* argv[]) {
     if (argc != 2) {
         std::cerr << "Usage: " << argv[0] << " OSMFILE\n";
-        exit(1);
+        std::exit(1);
     }
 
-    std::string input_filename = argv[1];
+    const std::string input_filename{argv[1]};
 
-    osmium::io::Reader reader(input_filename);
+    osmium::io::Reader reader{input_filename};
 
     CountHandler handler;
     osmium::apply(reader, handler);
