@@ -14,7 +14,7 @@ TEST_CASE("GeoJSON point geometry") {
     }
 
     SECTION("empty_point") {
-        REQUIRE_THROWS_AS(factory.create_point(osmium::Location{}), osmium::invalid_location);
+        REQUIRE_THROWS_AS(factory.create_point(osmium::Location{}), const osmium::invalid_location&);
     }
 
 }
@@ -50,17 +50,17 @@ TEST_CASE("GeoJSON linestring geometry") {
     SECTION("empty_linestring") {
         const auto& wnl = create_test_wnl_empty(buffer);
 
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::geometry_error);
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), osmium::geometry_error);
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all), osmium::geometry_error);
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all, osmium::geom::direction::backward), osmium::geometry_error);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all, osmium::geom::direction::backward), const osmium::geometry_error&);
     }
 
     SECTION("linestring with two same locations") {
         const auto& wnl = create_test_wnl_same_location(buffer);
 
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::geometry_error);
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), osmium::geometry_error);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), const osmium::geometry_error&);
 
         {
             const std::string json{factory.create_linestring(wnl, osmium::geom::use_nodes::all)};
@@ -75,7 +75,7 @@ TEST_CASE("GeoJSON linestring geometry") {
 
     SECTION("linestring with undefined location") {
         const auto& wnl = create_test_wnl_undefined_location(buffer);
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::invalid_location);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::invalid_location&);
     }
 
 }
@@ -87,7 +87,7 @@ TEST_CASE("GeoJSON area geometry") {
     SECTION("area_1outer_0inner") {
         const osmium::Area& area = create_test_area_1outer_0inner(buffer);
 
-        REQUIRE(!area.is_multipolygon());
+        REQUIRE_FALSE(area.is_multipolygon());
         REQUIRE(std::distance(area.cbegin(), area.cend()) == 2);
         REQUIRE(area.subitems<osmium::OuterRing>().size() == area.num_rings().first);
 
@@ -98,7 +98,7 @@ TEST_CASE("GeoJSON area geometry") {
     SECTION("area_1outer_1inner") {
         const osmium::Area& area = create_test_area_1outer_1inner(buffer);
 
-        REQUIRE(!area.is_multipolygon());
+        REQUIRE_FALSE(area.is_multipolygon());
         REQUIRE(std::distance(area.cbegin(), area.cend()) == 3);
         REQUIRE(area.subitems<osmium::OuterRing>().size() == area.num_rings().first);
         REQUIRE(area.subitems<osmium::InnerRing>().size() == area.num_rings().second);
