@@ -19,7 +19,8 @@ TEST_CASE("Projection 4326") {
 
     const osmium::Location loc{1.0, 2.0};
     const osmium::geom::Coordinates c{1.0, 2.0};
-    REQUIRE(c == projection(loc));
+    REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+    REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
 }
 
 TEST_CASE("Projection 4326 from init string") {
@@ -29,15 +30,16 @@ TEST_CASE("Projection 4326 from init string") {
 
     const osmium::Location loc{1.0, 2.0};
     const osmium::geom::Coordinates c{1.0, 2.0};
-    REQUIRE(c == projection(loc));
+    REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+    REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
 }
 
 TEST_CASE("Creating projection from unknown init string") {
-    REQUIRE_THROWS_AS(osmium::geom::Projection projection{"abc"}, osmium::projection_error);
+    REQUIRE_THROWS_AS(osmium::geom::Projection{"abc"}, const osmium::projection_error&);
 }
 
 TEST_CASE("Creating projection from unknown EPSG code") {
-    REQUIRE_THROWS_AS(osmium::geom::Projection projection{9999999}, osmium::projection_error);
+    REQUIRE_THROWS_AS(osmium::geom::Projection{9999999}, const osmium::projection_error&);
 }
 
 TEST_CASE("Projection 3857") {
@@ -48,29 +50,29 @@ TEST_CASE("Projection 3857") {
     SECTION("Zero coordinates") {
         const osmium::Location loc{0.0, 0.0};
         const osmium::geom::Coordinates c{0.0, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.1));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.1));
+        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
     }
 
     SECTION("Max longitude") {
         const osmium::Location loc{180.0, 0.0};
         const osmium::geom::Coordinates c{20037508.34, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.1));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.1));
+        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
     }
 
     SECTION("Min longitude") {
         const osmium::Location loc{-180.0, 0.0};
         const osmium::geom::Coordinates c{-20037508.34, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.1));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.1));
+        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
     }
 
     SECTION("Max latitude") {
         const osmium::Location loc{0.0, 85.0511288};
         const osmium::geom::Coordinates c{0.0, 20037508.34};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.1));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.1));
+        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
     }
 }
 
@@ -80,29 +82,29 @@ TEST_CASE("MercatorProjection") {
     SECTION("Zero coordinates") {
         const osmium::Location loc{0.0, 0.0};
         const osmium::geom::Coordinates c{0.0, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.1));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.1));
+        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
     }
 
     SECTION("Max longitude") {
         const osmium::Location loc{180.0, 0.0};
         const osmium::geom::Coordinates c{20037508.34, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.1));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.1));
+        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
     }
 
     SECTION("Min longitude") {
         const osmium::Location loc{-180.0, 0.0};
         const osmium::geom::Coordinates c{-20037508.34, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.1));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.1));
+        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
     }
 
     SECTION("Max latitude") {
         const osmium::Location loc{0.0, 85.0511288};
         const osmium::geom::Coordinates c{0.0, 20037508.34};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.1));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.1));
+        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
     }
 }
 
@@ -118,8 +120,8 @@ TEST_CASE("Compare mercator implementations") {
 
         for (int n = 0; n < 10000; ++n) {
             const osmium::Location loc{dis_x(gen), dis_y(gen)};
-            REQUIRE(projection_merc(loc).x == Approx(projection_3857(loc).x).epsilon(0.1));
-            REQUIRE(projection_merc(loc).y == Approx(projection_3857(loc).y).epsilon(0.1));
+            REQUIRE(projection_merc(loc).x == Approx(projection_3857(loc).x).epsilon(0.00001));
+            REQUIRE(projection_merc(loc).y == Approx(projection_3857(loc).y).epsilon(0.00001));
         }
     }
 
