@@ -7,29 +7,25 @@
 #include "wnl_helper.hpp"
 
 TEST_CASE("WKT geometry for point") {
+    const osmium::geom::WKTFactory<> factory;
+    const std::string wkt{factory.create_point(osmium::Location{3.2, 4.2})};
+    REQUIRE(wkt == "POINT(3.2 4.2)");
+}
 
-    osmium::geom::WKTFactory<> factory;
-
-    SECTION("point") {
-        const std::string wkt{factory.create_point(osmium::Location{3.2, 4.2})};
-        REQUIRE(wkt == "POINT(3.2 4.2)");
-    }
-
-    SECTION("empty point") {
-        REQUIRE_THROWS_AS(factory.create_point(osmium::Location()), osmium::invalid_location);
-    }
-
+TEST_CASE("WKT geometry for empty point") {
+    const osmium::geom::WKTFactory<> factory;
+    REQUIRE_THROWS_AS(factory.create_point(osmium::Location()), const osmium::invalid_location&);
 }
 
 TEST_CASE("WKT geometry for point in ekwt") {
-    osmium::geom::WKTFactory<> factory(7, osmium::geom::wkt_type::ewkt);
+    const osmium::geom::WKTFactory<> factory{7, osmium::geom::wkt_type::ewkt};
 
     const std::string wkt{factory.create_point(osmium::Location{3.2, 4.2})};
     REQUIRE(wkt == "SRID=4326;POINT(3.2 4.2)");
 }
 
 TEST_CASE("WKT geometry for point in ekwt in web mercator") {
-    osmium::geom::WKTFactory<osmium::geom::MercatorProjection> factory(2, osmium::geom::wkt_type::ewkt);
+    const osmium::geom::WKTFactory<osmium::geom::MercatorProjection> factory{2, osmium::geom::wkt_type::ewkt};
 
     const std::string wkt{factory.create_point(osmium::Location{3.2, 4.2})};
     REQUIRE(wkt == "SRID=3857;POINT(356222.37 467961.14)");
@@ -67,17 +63,17 @@ TEST_CASE("WKT geometry factory") {
     SECTION("empty linestring") {
         const auto& wnl = create_test_wnl_empty(buffer);
 
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::geometry_error);
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), osmium::geometry_error);
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all), osmium::geometry_error);
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all, osmium::geom::direction::backward), osmium::geometry_error);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all), const osmium::geometry_error&);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::all, osmium::geom::direction::backward), const osmium::geometry_error&);
     }
 
     SECTION("linestring with two same locations") {
         const auto& wnl = create_test_wnl_same_location(buffer);
 
         SECTION("unique forwards") {
-            REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::geometry_error);
+            REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::geometry_error&);
 
             try {
                 factory.create_linestring(wnl);
@@ -88,7 +84,7 @@ TEST_CASE("WKT geometry factory") {
         }
 
         SECTION("unique backwards") {
-            REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), osmium::geometry_error);
+            REQUIRE_THROWS_AS(factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward), const osmium::geometry_error&);
         }
 
         SECTION("all forwards") {
@@ -105,7 +101,7 @@ TEST_CASE("WKT geometry factory") {
     SECTION("linestring with undefined location") {
         const auto& wnl = create_test_wnl_undefined_location(buffer);
 
-        REQUIRE_THROWS_AS(factory.create_linestring(wnl), osmium::invalid_location);
+        REQUIRE_THROWS_AS(factory.create_linestring(wnl), const osmium::invalid_location&);
     }
 
     SECTION("area with one outer and no inner rings") {
