@@ -7,6 +7,7 @@
 #include <osmium/index/map/dense_mem_array.hpp>
 #include <osmium/index/map/dense_mmap_array.hpp>
 #include <osmium/index/map/dummy.hpp>
+#include <osmium/index/map/flex_mem.hpp>
 #include <osmium/index/map/sparse_file_array.hpp>
 #include <osmium/index/map/sparse_mem_array.hpp>
 #include <osmium/index/map/sparse_mem_map.hpp>
@@ -24,17 +25,17 @@ void test_func_all(TIndex& index) {
     const osmium::Location loc1{1.2, 4.5};
     const osmium::Location loc2{3.5, -7.2};
 
-    REQUIRE_THROWS_AS(index.get(id1), osmium::not_found);
+    REQUIRE_THROWS_AS(index.get(id1), const osmium::not_found&);
 
     index.set(id1, loc1);
     index.set(id2, loc2);
 
     index.sort();
 
-    REQUIRE_THROWS_AS(index.get(0), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(1), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(5), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
+    REQUIRE_THROWS_AS(index.get(0), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(1), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(5), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
     REQUIRE_THROWS_WITH(index.get(0), "id 0 not found");
     REQUIRE_THROWS_WITH(index.get(1), "id 1 not found");
 
@@ -62,10 +63,10 @@ void test_func_real(TIndex& index) {
     REQUIRE(loc1 == index.get_noexcept(id1));
     REQUIRE(loc2 == index.get_noexcept(id2));
 
-    REQUIRE_THROWS_AS(index.get(0), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(1), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(5), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
+    REQUIRE_THROWS_AS(index.get(0), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(1), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(5), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
 
     REQUIRE(index.get_noexcept(0) == osmium::Location{});
     REQUIRE(index.get_noexcept(1) == osmium::Location{});
@@ -74,13 +75,13 @@ void test_func_real(TIndex& index) {
 
     index.clear();
 
-    REQUIRE_THROWS_AS(index.get(id1), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(id2), osmium::not_found);
+    REQUIRE_THROWS_AS(index.get(id1), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(id2), const osmium::not_found&);
 
-    REQUIRE_THROWS_AS(index.get(0), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(1), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(5), osmium::not_found);
-    REQUIRE_THROWS_AS(index.get(100), osmium::not_found);
+    REQUIRE_THROWS_AS(index.get(0), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(1), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(5), const osmium::not_found&);
+    REQUIRE_THROWS_AS(index.get(100), const osmium::not_found&);
 
     REQUIRE(index.get_noexcept(id1) == osmium::Location{});
     REQUIRE(index.get_noexcept(id2) == osmium::Location{});
@@ -180,15 +181,67 @@ TEST_CASE("Map Id to location: SparseMemArray") {
     test_func_real<index_type>(index2);
 }
 
+TEST_CASE("Map Id to location: FlexMem sparse") {
+    using index_type = osmium::index::map::FlexMem<osmium::unsigned_object_id_type, osmium::Location>;
+
+    index_type index1;
+    test_func_all<index_type>(index1);
+
+    index_type index2;
+    test_func_real<index_type>(index2);
+}
+
+TEST_CASE("Map Id to location: FlexMem dense") {
+    using index_type = osmium::index::map::FlexMem<osmium::unsigned_object_id_type, osmium::Location>;
+
+    index_type index1{true};
+    test_func_all<index_type>(index1);
+
+    index_type index2{true};
+    test_func_real<index_type>(index2);
+}
+
+TEST_CASE("Map Id to location: FlexMem switch") {
+    using index_type = osmium::index::map::FlexMem<osmium::unsigned_object_id_type, osmium::Location>;
+
+    const osmium::Location loc1{1.1, 1.2};
+    const osmium::Location loc2{2.2, -9.4};
+
+    index_type index;
+
+    REQUIRE(index.size() == 0);
+
+    index.set(17, loc1);
+    index.set(99, loc2);
+
+    REQUIRE_FALSE(index.is_dense());
+    REQUIRE(index.size() == 2);
+    REQUIRE(index.get_noexcept(0) == osmium::Location{});
+    REQUIRE(index.get_noexcept(1) == osmium::Location{});
+    REQUIRE(index.get_noexcept(17) == loc1);
+    REQUIRE(index.get_noexcept(99) == loc2);
+    REQUIRE(index.get_noexcept(2000000000) == osmium::Location{});
+
+    index.switch_to_dense();
+
+    REQUIRE(index.is_dense());
+    REQUIRE(index.size() >= 2);
+    REQUIRE(index.get_noexcept(0) == osmium::Location{});
+    REQUIRE(index.get_noexcept(1) == osmium::Location{});
+    REQUIRE(index.get_noexcept(17) == loc1);
+    REQUIRE(index.get_noexcept(99) == loc2);
+    REQUIRE(index.get_noexcept(2000000000) == osmium::Location{});
+}
+
 TEST_CASE("Map Id to location: Dynamic map choice") {
     using map_type = osmium::index::map::Map<osmium::unsigned_object_id_type, osmium::Location>;
     const auto& map_factory = osmium::index::MapFactory<osmium::unsigned_object_id_type, osmium::Location>::instance();
 
     const std::vector<std::string> map_type_names = map_factory.map_types();
-    REQUIRE(map_type_names.size() >= 5);
+    REQUIRE(map_type_names.size() >= 6);
 
-    REQUIRE_THROWS_AS(map_factory.create_map(""), osmium::map_factory_error);
-    REQUIRE_THROWS_AS(map_factory.create_map("does not exist"), osmium::map_factory_error);
+    REQUIRE_THROWS_AS(map_factory.create_map(""), const osmium::map_factory_error&);
+    REQUIRE_THROWS_AS(map_factory.create_map("does not exist"), const osmium::map_factory_error&);
     REQUIRE_THROWS_WITH(map_factory.create_map(""), "Need non-empty map type name");
     REQUIRE_THROWS_WITH(map_factory.create_map("does not exist"), "Support for map type 'does not exist' not compiled into this binary");
 
