@@ -54,20 +54,36 @@ TEST_CASE("Reader can be initialized with string") {
     osmium::apply(reader, handler);
 }
 
+TEST_CASE("Reader can be initialized with user-provided pool") {
+    osmium::thread::Pool pool{4};
+    osmium::io::File file{with_data_dir("t/io/data.osm")};
+    osmium::io::Reader reader{file, pool};
+    osmium::handler::Handler handler;
+
+    osmium::apply(reader, handler);
+}
+
 TEST_CASE("Reader should throw after eof") {
     osmium::io::File file{with_data_dir("t/io/data.osm")};
     osmium::io::Reader reader{file};
 
-    REQUIRE(!reader.eof());
+    SECTION("Get header") {
+        const auto header = reader.header();
+        REQUIRE(header.get("generator") == "testdata");
+        REQUIRE_FALSE(reader.eof());
+    }
+
+    REQUIRE_FALSE(reader.eof());
 
     while (osmium::memory::Buffer buffer = reader.read()) {
     }
 
     REQUIRE(reader.eof());
 
-    REQUIRE_THROWS_AS({
-        reader.read();
-    }, osmium::io_error);
+    REQUIRE_THROWS_AS(reader.read(), const osmium::io_error&);
+
+    reader.close();
+    REQUIRE(reader.eof());
 }
 
 TEST_CASE("Reader should not hang when apply() is called twice on reader") {
@@ -76,9 +92,7 @@ TEST_CASE("Reader should not hang when apply() is called twice on reader") {
     osmium::handler::Handler handler;
 
     osmium::apply(reader, handler);
-    REQUIRE_THROWS_AS({
-        osmium::apply(reader, handler);
-    }, osmium::io_error);
+    REQUIRE_THROWS_AS(osmium::apply(reader, handler), const osmium::io_error&);
 }
 
 TEST_CASE("Reader should work with a buffer with uncompressed data") {
@@ -137,7 +151,7 @@ TEST_CASE("Reader should work with a buffer with bzip2-compressed data") {
 
 TEST_CASE("Reader should decode zero node positions in history (XML)") {
     osmium::io::Reader reader{with_data_dir("t/io/deleted_nodes.osh"),
-                                osmium::osm_entity_bits::node};
+                              osmium::osm_entity_bits::node};
     ZeroPositionNodeCountHandler handler;
 
     REQUIRE(handler.count == 0);
@@ -151,7 +165,7 @@ TEST_CASE("Reader should decode zero node positions in history (XML)") {
 
 TEST_CASE("Reader should decode zero node positions in history (PBF)") {
     osmium::io::Reader reader{with_data_dir("t/io/deleted_nodes.osh.pbf"),
-                                osmium::osm_entity_bits::node};
+                              osmium::osm_entity_bits::node};
     ZeroPositionNodeCountHandler handler;
 
     REQUIRE(handler.count == 0);
@@ -164,27 +178,21 @@ TEST_CASE("Reader should decode zero node positions in history (PBF)") {
 }
 
 TEST_CASE("Reader should fail with nonexistent file") {
-    REQUIRE_THROWS({
-        osmium::io::Reader reader{with_data_dir("t/io/nonexistent-file.osm")};
-    });
+    REQUIRE_THROWS(osmium::io::Reader{with_data_dir("t/io/nonexistent-file.osm")});
 }
 
 TEST_CASE("Reader should fail with nonexistent file (gz)") {
-    REQUIRE_THROWS({
-        osmium::io::Reader reader{with_data_dir("t/io/nonexistent-file.osm.gz")};
-    });
+    REQUIRE_THROWS(osmium::io::Reader{with_data_dir("t/io/nonexistent-file.osm.gz")});
 }
 
 TEST_CASE("Reader should fail with nonexistent file (pbf)") {
-    REQUIRE_THROWS({
-        osmium::io::Reader reader{with_data_dir("t/io/nonexistent-file.osm.pbf")};
-    });
+    REQUIRE_THROWS(osmium::io::Reader{with_data_dir("t/io/nonexistent-file.osm.pbf")});
 }
 
 TEST_CASE("Reader should work when there is an exception in main thread before getting header") {
     try {
         osmium::io::Reader reader{with_data_dir("t/io/data.osm")};
-        REQUIRE(!reader.eof());
+        REQUIRE_FALSE(reader.eof());
         throw std::runtime_error{"foo"};
     } catch (...) {
     }
@@ -193,7 +201,7 @@ TEST_CASE("Reader should work when there is an exception in main thread before g
 TEST_CASE("Reader should work when there is an exception in main thread while reading") {
     try {
         osmium::io::Reader reader{with_data_dir("t/io/data.osm")};
-        REQUIRE(!reader.eof());
+        REQUIRE_FALSE(reader.eof());
         auto header = reader.header();
         throw std::runtime_error{"foo"};
     } catch (...) {
@@ -206,3 +214,44 @@ TEST_CASE("Applying rvalue handler on reader") {
     osmium::apply(reader, NullHandler{});
 }
 
+TEST_CASE("Can call read() exactly once on Reader with entity_bits nothing") {
+    osmium::io::File file{with_data_dir("t/io/data.osm")};
+    osmium::io::Reader reader{file, osmium::osm_entity_bits::nothing};
+    REQUIRE_FALSE(reader.eof());
+
+    SECTION("Get header") {
+        const auto header = reader.header();
+        REQUIRE(header.get("generator") == "testdata");
+        REQUIRE_FALSE(reader.eof());
+    }
+
+    osmium::memory::Buffer buffer = reader.read();
+    REQUIRE_FALSE(buffer);
+    REQUIRE(reader.eof());
+    REQUIRE_THROWS_AS(reader.read(), const osmium::io_error&);
+
+    reader.close();
+    REQUIRE(reader.eof());
+}
+
+TEST_CASE("Can not read after close") {
+    osmium::io::File file{with_data_dir("t/io/data.osm")};
+    osmium::io::Reader reader{file};
+
+    SECTION("Get header") {
+        const auto header = reader.header();
+        REQUIRE(header.get("generator") == "testdata");
+        REQUIRE_FALSE(reader.eof());
+    }
+
+    REQUIRE_FALSE(reader.eof());
+
+    osmium::memory::Buffer buffer = reader.read();
+    REQUIRE(buffer);
+    REQUIRE_FALSE(reader.eof());
+
+    reader.close();
+    REQUIRE(reader.eof());
+    REQUIRE_THROWS_AS(reader.read(), const osmium::io_error&);
+}
+
