@@ -62,11 +62,11 @@ TEST_CASE("Write with mock compressor") {
 
         fail_in = "constructor";
 
-        REQUIRE_THROWS_AS({
+        REQUIRE_THROWS_AS([&](){
             osmium::io::Writer writer("test-writer-mock-fail-on-construction.osm.gz", header, osmium::io::overwrite::allow);
             writer(std::move(buffer));
             writer.close();
-        }, std::logic_error);
+        }(), const std::logic_error&);
 
     }
 
@@ -74,11 +74,11 @@ TEST_CASE("Write with mock compressor") {
 
         fail_in = "write";
 
-        REQUIRE_THROWS_AS({
+        REQUIRE_THROWS_AS([&](){
             osmium::io::Writer writer("test-writer-mock-fail-on-write.osm.gz", header, osmium::io::overwrite::allow);
             writer(std::move(buffer));
             writer.close();
-        }, std::logic_error);
+        }(), const std::logic_error&);
 
     }
 
@@ -86,11 +86,11 @@ TEST_CASE("Write with mock compressor") {
 
         fail_in = "close";
 
-        REQUIRE_THROWS_AS({
+        REQUIRE_THROWS_AS([&](){
             osmium::io::Writer writer("test-writer-mock-fail-on-close.osm.gz", header, osmium::io::overwrite::allow);
             writer(std::move(buffer));
             writer.close();
-        }, std::logic_error);
+        }(), const std::logic_error&);
 
     }
 
