@@ -1,155 +1,156 @@
 #include "catch.hpp"
 
+#include <limits>
 #include <sstream>
 #include <type_traits>
 
 #include <osmium/osm/location.hpp>
 
-TEST_CASE("Location") {
-
 // fails on MSVC and doesn't really matter
 // static_assert(std::is_literal_type<osmium::Location>::value, "osmium::Location not literal type");
 
-    SECTION("instantiation_with_default_parameters") {
-        osmium::Location loc;
-        REQUIRE(!loc);
-        REQUIRE_THROWS_AS(loc.lon(), osmium::invalid_location);
-        REQUIRE_THROWS_AS(loc.lat(), osmium::invalid_location);
-    }
+TEST_CASE("Location instantiation with default parameters") {
+    const osmium::Location loc;
+    REQUIRE_FALSE(loc);
+    REQUIRE_FALSE(loc.is_defined());
+    REQUIRE(loc.is_undefined());
+    REQUIRE_THROWS_AS(loc.lon(), const osmium::invalid_location&);
+    REQUIRE_THROWS_AS(loc.lat(), const osmium::invalid_location&);
+}
 
-    SECTION("instantiation_with_double_parameters") {
-        osmium::Location loc1(1.2, 4.5);
-        REQUIRE(!!loc1);
-        REQUIRE(12000000 == loc1.x());
-        REQUIRE(45000000 == loc1.y());
-        REQUIRE(1.2 == loc1.lon());
-        REQUIRE(4.5 == loc1.lat());
+TEST_CASE("Location instantiation with double parameters") {
+    const osmium::Location loc1{1.2, 4.5};
+    REQUIRE(bool(loc1));
+    REQUIRE(loc1.is_defined());
+    REQUIRE_FALSE(loc1.is_undefined());
+    REQUIRE(12000000 == loc1.x());
+    REQUIRE(45000000 == loc1.y());
+    REQUIRE(1.2 == Approx(loc1.lon()));
+    REQUIRE(4.5 == Approx(loc1.lat()));
 
-        osmium::Location loc2(loc1);
-        REQUIRE(4.5 == loc2.lat());
+    const osmium::Location loc2{loc1};
+    REQUIRE(4.5 == Approx(loc2.lat()));
 
-        osmium::Location loc3 = loc1;
-        REQUIRE(4.5 == loc3.lat());
-    }
+    const osmium::Location loc3 = loc1;
+    REQUIRE(4.5 == Approx(loc3.lat()));
+}
 
-    SECTION("instantiation_with_double_parameters_constructor_with_universal_initializer") {
-        osmium::Location loc { 2.2, 3.3 };
-        REQUIRE(2.2 == loc.lon());
-        REQUIRE(3.3 == loc.lat());
-    }
+TEST_CASE("Location instantiation with double parameters constructor with universal initializer") {
+    const osmium::Location loc{2.2, 3.3};
+    REQUIRE(2.2 == Approx(loc.lon()));
+    REQUIRE(3.3 == Approx(loc.lat()));
+}
 
-    SECTION("instantiation_with_double_parameters_constructor_with_initializer_list") {
-        osmium::Location loc({ 4.4, 5.5 });
-        REQUIRE(4.4 == loc.lon());
-        REQUIRE(5.5 == loc.lat());
-    }
+TEST_CASE("Location instantiation with double parameters constructor with initializer list") {
+    const osmium::Location loc({4.4, 5.5});
+    REQUIRE(4.4 == Approx(loc.lon()));
+    REQUIRE(5.5 == Approx(loc.lat()));
+}
 
-    SECTION("instantiation_with_double_parameters_operator_equal") {
-        osmium::Location loc = { 5.5, 6.6 };
-        REQUIRE(5.5 == loc.lon());
-        REQUIRE(6.6 == loc.lat());
-    }
+TEST_CASE("Location instantiation with double parameters operator equal") {
+    const osmium::Location loc = {5.5, 6.6};
+    REQUIRE(5.5 == Approx(loc.lon()));
+    REQUIRE(6.6 == Approx(loc.lat()));
+}
 
-    SECTION("equality") {
-        osmium::Location loc1(1.2, 4.5);
-        osmium::Location loc2(1.2, 4.5);
-        osmium::Location loc3(1.5, 1.5);
-        REQUIRE(loc1 == loc2);
-        REQUIRE(loc1 != loc3);
-    }
+TEST_CASE("Location equality") {
+    const osmium::Location loc1{1.2, 4.5};
+    const osmium::Location loc2{1.2, 4.5};
+    const osmium::Location loc3{1.5, 1.5};
+    REQUIRE(loc1 == loc2);
+    REQUIRE(loc1 != loc3);
+}
 
-    SECTION("order") {
-        REQUIRE(osmium::Location(-1.2, 10.0) < osmium::Location(1.2, 10.0));
-        REQUIRE(osmium::Location(1.2, 10.0) > osmium::Location(-1.2, 10.0));
+TEST_CASE("Location order") {
+    REQUIRE(osmium::Location(-1.2, 10.0) < osmium::Location(1.2, 10.0));
+    REQUIRE(osmium::Location(1.2, 10.0) > osmium::Location(-1.2, 10.0));
 
-        REQUIRE(osmium::Location(10.2, 20.0) < osmium::Location(11.2, 20.2));
-        REQUIRE(osmium::Location(10.2, 20.2) < osmium::Location(11.2, 20.0));
-        REQUIRE(osmium::Location(11.2, 20.2) > osmium::Location(10.2, 20.0));
-    }
+    REQUIRE(osmium::Location(10.2, 20.0) < osmium::Location(11.2, 20.2));
+    REQUIRE(osmium::Location(10.2, 20.2) < osmium::Location(11.2, 20.0));
+    REQUIRE(osmium::Location(11.2, 20.2) > osmium::Location(10.2, 20.0));
+}
 
-    SECTION("validity") {
-        REQUIRE(osmium::Location(0.0, 0.0).valid());
-        REQUIRE(osmium::Location(1.2, 4.5).valid());
-        REQUIRE(osmium::Location(-1.2, 4.5).valid());
-        REQUIRE(osmium::Location(-180.0, -90.0).valid());
-        REQUIRE(osmium::Location(180.0, -90.0).valid());
-        REQUIRE(osmium::Location(-180.0, 90.0).valid());
-        REQUIRE(osmium::Location(180.0, 90.0).valid());
+TEST_CASE("Location validity") {
+    REQUIRE(osmium::Location(0.0, 0.0).valid());
+    REQUIRE(osmium::Location(1.2, 4.5).valid());
+    REQUIRE(osmium::Location(-1.2, 4.5).valid());
+    REQUIRE(osmium::Location(-180.0, -90.0).valid());
+    REQUIRE(osmium::Location(180.0, -90.0).valid());
+    REQUIRE(osmium::Location(-180.0, 90.0).valid());
+    REQUIRE(osmium::Location(180.0, 90.0).valid());
 
-        REQUIRE(!osmium::Location(200.0, 4.5).valid());
-        REQUIRE(!osmium::Location(-1.2, -100.0).valid());
-        REQUIRE(!osmium::Location(-180.0, 90.005).valid());
-    }
+    REQUIRE_FALSE(osmium::Location(200.0, 4.5).valid());
+    REQUIRE_FALSE(osmium::Location(-1.2, -100.0).valid());
+    REQUIRE_FALSE(osmium::Location(-180.0, 90.005).valid());
+}
 
 
-    SECTION("output_to_iterator_comma_separator") {
-        char buffer[100];
-        osmium::Location loc(-3.2, 47.3);
-        *loc.as_string(buffer, ',') = 0;
-        REQUIRE(std::string("-3.2,47.3") == buffer);
-    }
+TEST_CASE("Location output to iterator comma separator") {
+    char buffer[100];
+    const osmium::Location loc{-3.2, 47.3};
+    *loc.as_string(buffer, ',') = 0;
+    REQUIRE(std::string("-3.2,47.3") == buffer);
+}
 
-    SECTION("output_to_iterator_space_separator") {
-        char buffer[100];
-        osmium::Location loc(0.0, 7.0);
-        *loc.as_string(buffer, ' ') = 0;
-        REQUIRE(std::string("0 7") == buffer);
-    }
+TEST_CASE("Location output to iterator space separator") {
+    char buffer[100];
+    const osmium::Location loc{0.0, 7.0};
+    *loc.as_string(buffer, ' ') = 0;
+    REQUIRE(std::string("0 7") == buffer);
+}
 
-    SECTION("output_to_iterator_check_precision") {
-        char buffer[100];
-        osmium::Location loc(-179.9999999, -90.0);
-        *loc.as_string(buffer, ' ') = 0;
-        REQUIRE(std::string("-179.9999999 -90") == buffer);
-    }
+TEST_CASE("Location output to iterator check precision") {
+    char buffer[100];
+    const osmium::Location loc{-179.9999999, -90.0};
+    *loc.as_string(buffer, ' ') = 0;
+    REQUIRE(std::string("-179.9999999 -90") == buffer);
+}
 
-    SECTION("output_to_iterator_undefined_location") {
-        char buffer[100];
-        osmium::Location loc;
-        REQUIRE_THROWS_AS(loc.as_string(buffer, ','), osmium::invalid_location);
-    }
+TEST_CASE("Location output to iterator undefined location") {
+    char buffer[100];
+    const osmium::Location loc;
+    REQUIRE_THROWS_AS(loc.as_string(buffer, ','), const osmium::invalid_location&);
+}
 
-    SECTION("output_to_string_comman_separator") {
-        std::string s;
-        osmium::Location loc(-3.2, 47.3);
-        loc.as_string(std::back_inserter(s), ',');
-        REQUIRE(s == "-3.2,47.3");
-    }
+TEST_CASE("Location output to string comman separator") {
+    std::string s;
+    const osmium::Location loc{-3.2, 47.3};
+    loc.as_string(std::back_inserter(s), ',');
+    REQUIRE(s == "-3.2,47.3");
+}
 
-    SECTION("output_to_string_space_separator") {
-        std::string s;
-        osmium::Location loc(0.0, 7.0);
-        loc.as_string(std::back_inserter(s), ' ');
-        REQUIRE(s == "0 7");
-    }
+TEST_CASE("Location output to string space separator") {
+    std::string s;
+    const osmium::Location loc{0.0, 7.0};
+    loc.as_string(std::back_inserter(s), ' ');
+    REQUIRE(s == "0 7");
+}
 
-    SECTION("output_to_string_check_precision") {
-        std::string s;
-        osmium::Location loc(-179.9999999, -90.0);
-        loc.as_string(std::back_inserter(s), ' ');
-        REQUIRE(s == "-179.9999999 -90");
-    }
+TEST_CASE("Location output to string check precision") {
+    std::string s;
+    const osmium::Location loc{-179.9999999, -90.0};
+    loc.as_string(std::back_inserter(s), ' ');
+    REQUIRE(s == "-179.9999999 -90");
+}
 
-    SECTION("output_to_string_undefined_location") {
-        std::string s;
-        osmium::Location loc;
-        REQUIRE_THROWS_AS(loc.as_string(std::back_inserter(s), ','), osmium::invalid_location);
-    }
+TEST_CASE("Location output to string undefined location") {
+    std::string s;
+    const osmium::Location loc;
+    REQUIRE_THROWS_AS(loc.as_string(std::back_inserter(s), ','), const osmium::invalid_location&);
+}
 
-    SECTION("output_defined") {
-        osmium::Location p(-3.20, 47.30);
-        std::stringstream out;
-        out << p;
-        REQUIRE(out.str() == "(-3.2,47.3)");
-    }
-
-    SECTION("output_undefined") {
-        osmium::Location p;
-        std::stringstream out;
-        out << p;
-        REQUIRE(out.str() == "(undefined,undefined)");
-    }
+TEST_CASE("Location output defined") {
+    const osmium::Location loc{-3.20, 47.30};
+    std::stringstream out;
+    out << loc;
+    REQUIRE(out.str() == "(-3.2,47.3)");
+}
 
+TEST_CASE("Location output undefined") {
+    const osmium::Location loc;
+    std::stringstream out;
+    out << loc;
+    REQUIRE(out.str() == "(undefined,undefined)");
 }
 
 TEST_CASE("Location hash") {
@@ -188,10 +189,10 @@ void F(const char* s) {
     strm += s;
     const char* x = strm.c_str();
     const char** data = &x;
-    REQUIRE_THROWS_AS(osmium::detail::string_to_location_coordinate(data), osmium::invalid_location);
+    REQUIRE_THROWS_AS(osmium::detail::string_to_location_coordinate(data), const osmium::invalid_location&);
     ++x;
     data = &x;
-    REQUIRE_THROWS_AS(osmium::detail::string_to_location_coordinate(data), osmium::invalid_location);
+    REQUIRE_THROWS_AS(osmium::detail::string_to_location_coordinate(data), const osmium::invalid_location&);
 }
 
 TEST_CASE("Parsing coordinates from strings") {
@@ -336,7 +337,7 @@ TEST_CASE("Parsing coordinates from strings") {
 TEST_CASE("Parsing min coordinate from string") {
     const char* minval = "-214.7483648";
     const char** data = &minval;
-    REQUIRE(osmium::detail::string_to_location_coordinate(data) == -2147483648l);
+    REQUIRE(osmium::detail::string_to_location_coordinate(data) == std::numeric_limits<int32_t>::min());
 }
 
 TEST_CASE("Writing zero coordinate into string") {
@@ -383,26 +384,34 @@ TEST_CASE("Writing coordinate into string") {
 TEST_CASE("Writing min coordinate into string") {
     std::string buffer;
 
-    osmium::detail::append_location_coordinate_to_string(std::back_inserter(buffer), -2147483648l);
+    osmium::detail::append_location_coordinate_to_string(std::back_inserter(buffer), std::numeric_limits<int32_t>::min());
     REQUIRE(buffer == "-214.7483648");
 }
 
 TEST_CASE("set lon/lat from string") {
     osmium::Location loc;
+    REQUIRE(loc.is_undefined());
+    REQUIRE_FALSE(loc.is_defined());
+    REQUIRE_FALSE(loc.valid());
+
     loc.set_lon("1.2");
+    REQUIRE_FALSE(loc.is_undefined());
+    REQUIRE(loc.is_defined());
+    REQUIRE_FALSE(loc.valid());
+
     loc.set_lat("3.4");
+    REQUIRE_FALSE(loc.is_undefined());
+    REQUIRE(loc.is_defined());
+    REQUIRE(loc.valid());
+
     REQUIRE(loc.lon() == Approx(1.2));
     REQUIRE(loc.lat() == Approx(3.4));
 }
 
 TEST_CASE("set lon/lat from string with trailing characters") {
     osmium::Location loc;
-    REQUIRE_THROWS_AS({
-        loc.set_lon("1.2x");
-    }, osmium::invalid_location);
-    REQUIRE_THROWS_AS({
-        loc.set_lat("3.4e1 ");
-    }, osmium::invalid_location);
+    REQUIRE_THROWS_AS(loc.set_lon("1.2x"), const osmium::invalid_location&);
+    REQUIRE_THROWS_AS(loc.set_lat("3.4e1 "), const osmium::invalid_location&);
 }
 
 TEST_CASE("set lon/lat from string with trailing characters using partial") {
